@@ -17,7 +17,7 @@
 */
 #include "config.h"
 
-#ifdef USE_SMARTCARD
+#ifdef USE_SMARTCARD_012
 #include <vreader.h>
 #endif
 
@@ -36,7 +36,7 @@
  * @section_id:
  * @see_also: #SpiceSmartcardManager, #SpiceSession
  * @stability: API Stable (channel in development)
- * @include: channel-smartcard.h
+ * @include: spice-client.h
  *
  * The Spice protocol defines a set of messages to forward smartcard
  * information from the Spice client to the VM. This channel handles
@@ -241,10 +241,10 @@ smartcard_message_free(SpiceSmartcardChannelMessage *message)
 {
     if (message->message)
         spice_msg_out_unref(message->message);
-    g_slice_free(SpiceSmartcardChannelMessage, message);
+    g_free(message);
 }
 
-#if USE_SMARTCARD
+#ifdef USE_SMARTCARD
 static gboolean is_attached_to_server(VReader *reader)
 {
     return (vreader_get_id(reader) != (vreader_id_t)-1);
@@ -301,7 +301,7 @@ smartcard_message_new(VSCMsgType msg_type, SpiceMsgOut *msg_out)
 {
     SpiceSmartcardChannelMessage *message;
 
-    message = g_slice_new0(SpiceSmartcardChannelMessage);
+    message = g_new0(SpiceSmartcardChannelMessage, 1);
     message->message = msg_out;
     message->message_type = msg_type;
 
