@@ -22,10 +22,14 @@
 
 #include "glib-compat.h"
 
-#ifdef USE_SMARTCARD
+#ifdef USE_SMARTCARD_012
 #include <vcard_emul.h>
 #include <vevent.h>
 #include <vreader.h>
+#else
+#ifdef USE_SMARTCARD
+#include <libcacard.h>
+#endif
 #endif
 
 #include "spice-client.h"
@@ -40,7 +44,7 @@
  * @section_id:
  * @see_also:
  * @stability: Stable
- * @include: smartcard-manager.h
+ * @include: spice-client.h
  *
  * #SpiceSmartcardManager monitors smartcard reader plugging/unplugging,
  * and smartcard insertions/removals. It also provides methods to handle
